@@ -17,18 +17,19 @@ class RequestHelper:
         self.key = os.getenv("SHUTTERSTOCK_KEY")
         self.secret = os.getenv("SHUTTERSTOCK_SECRET")
         self.token = os.getenv("SHUTTERSTOCK_API_TOKEN")
-        self.sandbox_mode = bool(os.getenv("SHUTTERSTOCK_SANDBOX"))
+        self.sandbox_mode = (
+            True if os.getenv("SHUTTERSTOCK_SANDBOX") == "true" else False
+        )
         self.custom_url = os.getenv("SHUTTERSTOCK_CUSTOM_URL")
 
         self._auth = None
-        self._headers = None
+        self._headers = {"User-Agent": "Shutterstock-CLI"}
 
         if self.token:
-            self._headers = {"Authorization": f"Bearer {self.token}"}
+            self._headers.update({"Authorization": f"Bearer {self.token}"})
 
         elif self.key and self.secret:
             self._auth = HTTPBasicAuth(self.key, self.secret)
-            self._headers = {}
 
     @property
     def headers(self):
